import streamlit as st
from langchain.prompts import PromptTemplate
from langchain.schema.runnable import RunnablePassthrough
from langchain.schema import StrOutputParser

from src.llm import LLMProvider, load_llm
from src.retriever import create_retriever
from src.settings import template
from src.utils import format_docs


@st.cache_resource(hash_funcs={LLMProvider: str})
def init_chain(llm_provider, docs_path):
    print("Initializing chain...")
    llm, embeddings = load_llm(llm_provider)
    retriever = create_retriever(docs_path, embeddings)

    prompt = PromptTemplate.from_template(template)
    chain = (
            {"context": retriever | format_docs, "question": RunnablePassthrough()}
            | prompt
            | llm
            | StrOutputParser()
    )

    return chain
