from langchain.document_loaders import PyPDFLoader
from langchain.text_splitter import RecursiveCharacterTextSplitter
from langchain.vectorstores.faiss import FAISS


def load_docs(path):
    loader = PyPDFLoader(path)
    return loader.load()


def process_docs(docs):
    text_splitter = RecursiveCharacterTextSplitter(
        chunk_size=500,
        chunk_overlap=100,
    )
    texts = text_splitter.split_documents(docs)
    return texts


def create_retriever(docs_path, embedding_model):
    print("Creating retruever...")
    docs = load_docs(docs_path)
    docs = process_docs(docs)
    db = FAISS.from_documents(docs, embedding_model)
    retriever = db.as_retriever()
    return retriever
